ChromaprintBindings class

Bindings for the chromaprint C library.

Constructors

ChromaprintBindings(DynamicLibrary dynamicLibrary)
The symbols are looked up in dynamicLibrary.
ChromaprintBindings.fromLookup(Pointer<T> lookup<T extends NativeType>(String symbolName))
The symbols are looked up with lookup.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

chromaprint_clear_fingerprint(Pointer<ChromaprintContext> ctx) int
Clears the current fingerprint data.
chromaprint_dealloc(Pointer<Void> ptr) → void
Frees memory allocated by chromaprint functions.
chromaprint_decode_fingerprint(Pointer<Char> encoded_fp, int encoded_size, Pointer<Pointer<Uint32>> fp, Pointer<Int> size, Pointer<Int> algorithm, int base64) int
Decodes a compressed fingerprint.
chromaprint_decode_fingerprint_header(Pointer<Char> encoded_fp, int encoded_size, Pointer<Int> size, Pointer<Int> algorithm, int base64) int
Decodes only the header of a compressed fingerprint.
chromaprint_encode_fingerprint(Pointer<Uint32> fp, int size, int algorithm, Pointer<Pointer<Char>> encoded_fp, Pointer<Int> encoded_size, int base64) int
Encodes a raw fingerprint to a compressed format.
chromaprint_feed(Pointer<ChromaprintContext> ctx, Pointer<Int16> data, int size) int
Feeds audio data to the fingerprinter.
chromaprint_finish(Pointer<ChromaprintContext> ctx) int
Finishes audio fingerprinting.
chromaprint_free(Pointer<ChromaprintContext> ctx) → void
Frees a chromaprint context.
chromaprint_get_algorithm(Pointer<ChromaprintContext> ctx) int
Returns the algorithm used by the context.
chromaprint_get_delay(Pointer<ChromaprintContext> ctx) int
Returns the delay in samples.
chromaprint_get_delay_ms(Pointer<ChromaprintContext> ctx) int
Returns the delay in milliseconds.
chromaprint_get_fingerprint(Pointer<ChromaprintContext> ctx, Pointer<Pointer<Char>> fingerprint) int
Gets the compressed fingerprint as a base64-encoded string.
chromaprint_get_fingerprint_hash(Pointer<ChromaprintContext> ctx, Pointer<Uint32> hash) int
Gets a hash of the fingerprint.
chromaprint_get_item_duration(Pointer<ChromaprintContext> ctx) int
Returns the item duration in samples.
chromaprint_get_item_duration_ms(Pointer<ChromaprintContext> ctx) int
Returns the item duration in milliseconds.
chromaprint_get_num_channels(Pointer<ChromaprintContext> ctx) int
Returns the number of channels configured on the context.
chromaprint_get_raw_fingerprint(Pointer<ChromaprintContext> ctx, Pointer<Pointer<Uint32>> fingerprint, Pointer<Int> size) int
Gets the raw fingerprint as an array of 32-bit unsigned integers.
chromaprint_get_raw_fingerprint_size(Pointer<ChromaprintContext> ctx, Pointer<Int> size) int
Gets the size of the raw fingerprint.
chromaprint_get_sample_rate(Pointer<ChromaprintContext> ctx) int
Returns the sample rate configured on the context.
chromaprint_get_version() Pointer<Char>
Returns the version string of the chromaprint library.
chromaprint_hash_fingerprint(Pointer<Uint32> fp, int size, Pointer<Uint32> hash) int
Computes a hash of a raw fingerprint.
chromaprint_new(int algorithm) Pointer<ChromaprintContext>
Creates a new chromaprint context.
chromaprint_set_option(Pointer<ChromaprintContext> ctx, Pointer<Char> name, int value) int
Sets an option on the context.
chromaprint_start(Pointer<ChromaprintContext> ctx, int sample_rate, int num_channels) int
Starts audio fingerprinting.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited