ChromaprintContext class final

Opaque chromaprint context.

Represents an opaque native chromaprint fingerprinting context. Instances are created by ChromaprintBindings.chromaprint_new and must be freed with ChromaprintBindings.chromaprint_free.

Inheritance

Constructors

ChromaprintContext()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited